@@ -1,7 +1,7 @@
 package Pod::Weaver::Plugin::Regexp::Pattern;
 
-our $DATE = '2019-12-17'; # DATE
-our $VERSION = '0.004'; # VERSION
+our $DATE = '2020-02-11'; # DATE
+our $VERSION = '0.005'; # VERSION
 
 use 5.010001;
 use Moose;
@@ -168,6 +168,17 @@ sub _process_module {
             });
     }
 
+    # mention some modules in See Also section
+    {
+        my @pod = (
+            "L<Regexp::Pattern>\n\n",
+            "Some utilities related to Regexp::Pattern: L<App::RegexpPatternUtils>, L<rpgrep> from L<App::rpgrep>.\n\n",
+        );
+        $self->add_text_to_section(
+            $document, join('', @pod), 'SEE ALSO',
+        );
+    }
+
     $self->log(["Generated POD for '%s'", $filename]);
 }
 
@@ -205,7 +216,7 @@ Pod::Weaver::Plugin::Regexp::Pattern - Plugin to use when building Regexp::Patte
 
 =head1 VERSION
 
-This document describes version 0.004 of Pod::Weaver::Plugin::Regexp::Pattern (from Perl distribution Pod-Weaver-Plugin-Regexp-Pattern), released on 2019-12-17.
+This document describes version 0.005 of Pod::Weaver::Plugin::Regexp::Pattern (from Perl distribution Pod-Weaver-Plugin-Regexp-Pattern), released on 2020-02-11.
 
 =head1 SYNOPSIS
 
@@ -226,6 +237,8 @@ Currently it does the following:
 
 =item * Add a Patterns section containing list of patterns contained in the module
 
+=item * Mention some modules in the See Also section, including Regexp::Pattern
+
 =back
 
 =for Pod::Coverage .*
@@ -260,7 +273,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2019, 2018, 2016 by perlancar@cpan.org.
+This software is copyright (c) 2020, 2019, 2018, 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
